# Fast Vindex: A faster version of Dask's vindex for advanced indexing with arrays.

*fast-vindex* is a faster and more flexible alternative to Dask's built-in `vindex` function, designed to improve performance when working with complex or high-dimensional array indexing.

```{warning}
While `fast-vindex` aims to offer significant performance improvements over Dask’s built-in `vindex`, it does **not currently support all features** of the official implementation.

For a detailed list of supported indexing patterns and limitations, please refer to the [Supported Features](#supported-features) page.
```

<!-- ````{grid} 1 2 2 2
:gutter: 4
:padding: 1 2 0 0

```{grid-item-card} Getting Started
:link: getting-started/index
:link-type: doc
New to *fast_vindex*? Check out the Getting Started Guide. It explains why *fast_vindex* exists.
```

```{grid-item-card} User Guide
:link: user-guide
:link-type: doc
The User Guide provides information on all the features of *fast_vindex* with explanations and examples.
```

```{grid-item-card} Development
:link: development/index
:link-type: doc
TO DO
```
```` -->


```{toctree}
  :maxdepth: 1
  :hidden:

getting-started/index
development/index
```
